==> foundation-2.6.1.tgz: package/SocialSkillshare/SocialSkillshare.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialSkillshare = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fill: "none",
    d: "M32.092 55.916h14.575c1.087 0 2.563 2.496 4.734 4.039v-1.776s-.07-1.053.348-1.69c.424-.639 1.308-.809 1.584-.809h14.575s4.401-.74 9.294-3.044l-53.794.514c4.642 2.082 8.684 2.766 8.684 2.766z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M16.868 55.111a24.875 24.875 0 01-1.061-.855c.247.396.609.703 1.061.855zm2.67-39.55h60.708v35.516c2.128-1.18 3.271-1.984 4.054-2.499v-35.05a2.03 2.03 0 00-2.03-2.028H17.508c-1.123 0-2.033.91-2.033 2.028v35.14c.771.486 1.878 1.301 4.063 2.52V15.561z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M87.791 47.978c-.523-.417-1.247-.415-2.396 0-.335.122-.674.325-1.095.6-.783.515-1.925 1.319-4.054 2.499-.657.36-1.373.748-2.241 1.183-.272.136-.534.247-.803.377-4.893 2.304-9.294 3.044-9.294 3.044H53.333c-.276 0-1.16.17-1.584.809-.418.638-.348 1.69-.348 1.69v1.776c.526.373 1.082.707 1.695.918 4.394 1.498 7.367.192 8.664-1.628 1.517-2.134 2.289-3.329 3.955-2.705 1.666.624 0 4.68-2.08 6.763-2.085 2.084-4.584 3.749-8.12 3.749-1.486 0-2.926-.223-4.114-.476v15.131c0 4.27 4.538 6.552 7.658 6.552 3.119 0 9.367-1.768 12.387-9.263 3.017-7.493-.205-17.381-.205-17.381s4.888-2.191 9.991-5.414c5.098-3.225 6.455-6.246 6.559-6.67.1-.427.516-1.136 0-1.554z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M63.635 63.303c2.08-2.083 3.746-6.139 2.08-6.763-1.666-.624-2.438.571-3.955 2.705-1.297 1.82-4.27 3.126-8.664 1.628-.613-.211-1.169-.545-1.695-.918-2.17-1.543-3.647-4.039-4.734-4.039H32.092s-4.043-.684-8.684-2.766c-.466-.21-.935-.418-1.411-.657a59.295 59.295 0 01-2.459-1.306c-2.185-1.219-3.292-2.033-4.063-2.52-.321-.203-.593-.355-.871-.455-1.144-.416-1.873-.416-2.394 0-.518.418-.104 1.128 0 1.553.08.325.913 2.184 3.596 4.49a26.416 26.416 0 002.963 2.181c5.098 3.227 9.991 5.412 9.991 5.412s-3.227 9.886-.205 17.381c3.018 7.494 9.263 9.27 12.385 9.27 3.123 0 7.661-2.297 7.661-6.564V65.804s1.152.42 2.799.771c1.188.253 2.628.476 4.114.476 3.537.001 6.036-1.664 8.121-3.748zm-2.618-28.922a9.059 9.059 0 00-9.058 9.057c0 4.999 4.055 9.056 9.058 9.056 4.998 0 9.052-4.057 9.052-9.056 0-5-4.054-9.057-9.052-9.057z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M39.544 34.381c-5 0-9.053 4.057-9.053 9.057 0 4.999 4.052 9.056 9.053 9.056 5.003 0 9.058-4.057 9.058-9.056 0-5-4.055-9.057-9.058-9.057z"
  }));
});
SocialSkillshare.displayName = 'SocialSkillshare';
export const SocialSkillshareDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialSkillshare/SocialSkillshare.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialSkillshare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fill: "none",
    d: "M32.092 55.916h14.575c1.087 0 2.563 2.496 4.734 4.039v-1.776s-.07-1.053.348-1.69c.424-.639 1.308-.809 1.584-.809h14.575s4.401-.74 9.294-3.044l-53.794.514c4.642 2.082 8.684 2.766 8.684 2.766z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M16.868 55.111a24.875 24.875 0 01-1.061-.855c.247.396.609.703 1.061.855zm2.67-39.55h60.708v35.516c2.128-1.18 3.271-1.984 4.054-2.499v-35.05a2.03 2.03 0 00-2.03-2.028H17.508c-1.123 0-2.033.91-2.033 2.028v35.14c.771.486 1.878 1.301 4.063 2.52V15.561z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M87.791 47.978c-.523-.417-1.247-.415-2.396 0-.335.122-.674.325-1.095.6-.783.515-1.925 1.319-4.054 2.499-.657.36-1.373.748-2.241 1.183-.272.136-.534.247-.803.377-4.893 2.304-9.294 3.044-9.294 3.044H53.333c-.276 0-1.16.17-1.584.809-.418.638-.348 1.69-.348 1.69v1.776c.526.373 1.082.707 1.695.918 4.394 1.498 7.367.192 8.664-1.628 1.517-2.134 2.289-3.329 3.955-2.705 1.666.624 0 4.68-2.08 6.763-2.085 2.084-4.584 3.749-8.12 3.749-1.486 0-2.926-.223-4.114-.476v15.131c0 4.27 4.538 6.552 7.658 6.552 3.119 0 9.367-1.768 12.387-9.263 3.017-7.493-.205-17.381-.205-17.381s4.888-2.191 9.991-5.414c5.098-3.225 6.455-6.246 6.559-6.67.1-.427.516-1.136 0-1.554z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M63.635 63.303c2.08-2.083 3.746-6.139 2.08-6.763-1.666-.624-2.438.571-3.955 2.705-1.297 1.82-4.27 3.126-8.664 1.628-.613-.211-1.169-.545-1.695-.918-2.17-1.543-3.647-4.039-4.734-4.039H32.092s-4.043-.684-8.684-2.766c-.466-.21-.935-.418-1.411-.657a59.295 59.295 0 01-2.459-1.306c-2.185-1.219-3.292-2.033-4.063-2.52-.321-.203-.593-.355-.871-.455-1.144-.416-1.873-.416-2.394 0-.518.418-.104 1.128 0 1.553.08.325.913 2.184 3.596 4.49a26.416 26.416 0 002.963 2.181c5.098 3.227 9.991 5.412 9.991 5.412s-3.227 9.886-.205 17.381c3.018 7.494 9.263 9.27 12.385 9.27 3.123 0 7.661-2.297 7.661-6.564V65.804s1.152.42 2.799.771c1.188.253 2.628.476 4.114.476 3.537.001 6.036-1.664 8.121-3.748zm-2.618-28.922a9.059 9.059 0 00-9.058 9.057c0 4.999 4.055 9.056 9.058 9.056 4.998 0 9.052-4.057 9.052-9.056 0-5-4.054-9.057-9.052-9.057z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M39.544 34.381c-5 0-9.053 4.057-9.053 9.057 0 4.999 4.052 9.056 9.053 9.056 5.003 0 9.058-4.057 9.058-9.056 0-5-4.055-9.057-9.058-9.057z"
  }));
});
SocialSkillshare.displayName = 'SocialSkillshare';
export var SocialSkillshareDimensions = {
  height: 100,
  width: 100
};
